@@ -154,7 +154,7 @@ penAFT.cv <- function(X, logY, delta,
     # Perform cross-validation
     # --------------------------------------------------------------------
     if(!is.null(cv.index)){
-      if(class(cv.index)!="list"){
+      if(!is.list(cv.index)){
         stop("Input cv.index must be a list!")
       } else {
         nfolds <- length(cv.index)
@@ -448,9 +448,9 @@ penAFT.cv <- function(X, logY, delta,
     "cv.err.linPred" = cv.err.linPred,
     "cv.err.obj" = cv.err.obj,
     "cv.index" = cv.index,
-    "lambda.min" = lambda[which.min(cv.err.linPred == min(cv.err.linPred))])
+    "lambda.min" = lambda[which.min(cv.err.linPred)])
   class(Result) <- "penAFT.cv"
  
   return(Result)
   
-}
\ No newline at end of file
+}
